==> appfs-21.02.tar.gz: usr/local/www/berogui/modules/Market/market_ajax.php <==
<?php
require_once("/usr/local/www/berogui/includes/Helper/Helper.php");

$exec_ajax = 1;
$invalid = array();

/* [CHECKING GET REQUEST] */
unset($_GET);

/* [CHECKING POST REQUEST] */
$list_post = array('del_param' => 'file-exists', 'menu' => 'select', 'get_installed' => 'select', 'a' => 'select', 'param' => 'id');

$list_options = array(	'del_param' 	=> array('/apps')	,
			'menu'		=> array('get')		,
			'get_installed'	=> array('get')		,
			'a'		=> array('get_app')	);

$_POST = Helper::sanitizePost($_POST, $list_post, $exec_ajax, $invalid, $list_options);

/* [EXECUTING AJAX] */
if (!$exec_ajax) {
        echo "<script>window.location='../../index.php?m=Market&error=1&request={$invalid['request']}&checkor={$invalid['checkor']}&key={$invalid['key']}'</script>";
	exit(1);
}

chdir("../..");
include "./includes/variables.php";
include_once("/usr/www/include/SQLite2ToSQLite3.php");
include "./misc/database.php";
$ba = new beroAri();
require_once("./includes/lang.php");
require_once('/usr/local/www/berogui/includes/session.php');

require_once('/usr/local/php/include/berocloud/SbcApi.php');
$cloud = new SbcApi(null, $ba);

function checkCloud() {
	global $cloud;
	$res = $cloud->send('getAppListCheck');
	$res .= "beroNetF231";
	return md5($res);
}

function getInstalledApps() {
	$table = "<table class='table table-striped table-bordered' id='table'>";
	$apps = Helper::getAppList();
	foreach ($apps as $file) {
		$table .= "
		<tr>
			<td>" . $file . "</td>
			<td>
			<img src='./includes/images/delete.png' onclick=\"del('" . $file . "');\"></img>
			</td>
		</tr>";
	}
	$table .= "</table><br/>";

	// TODO: is $error_msg useful ?
	return $error_msg . $table;
}

if (isset($_POST['get_installed'])) {
	echo getInstalledApps();
}
if ($_POST['a'] == 'get_app') {

	$result = checkCloud();
	$apps = $cloud->send('getAppList', array('app_key' => $result), array(), $info);
	if ($apps == false) {
		if ($info['http_code'] == 400 || $info['http_code'] == 401) {
			$table = "<font color='red'>Invalid app key</font><br/>";
		} 
		else {
			$table = "<font color='red'>Error, please check your cloud and network settings.</font><br/>";
		}
	}
	else {
		$apps = unserialize($apps);
		if (count($apps) >= 1 && is_array($apps)) {
			$table = "<table class='table table-striped table-bordered'>";
			$table .= "<tr>"
							. "<th></th>"
							. "<th>" . MARKET_NAME . "</th>"
							. "<th>" . MARKET_DESCRIPTION . "</th>"
							. "<th>" . MARKET_CATEGORY . "</th>"
							.	"<th>" . MARKET_VERSION . "</th>"
							. "<th>" . MARKET_PROVIDER . "</th>"
							. "</tr>";
			foreach ($apps as $app) {
				($app['providerLink'] != null) ? $providerLink = "<a href='" . $app['providerLink'] . "' target='_blank'>" . $app['provider'] . "</a>" : $providerLink = $app['provider'];
				($app['docuLink'] != null) ? $docuLink = "<br><a href='" . $app['docuLink'] . "' target='_blank'>Documentation</a>" : $docuLink = "";
				$table .= "<tr>"
					. "<td><input type='checkbox' class='installApp' value='" . $app['id'] . "'></td>"
					. "<td>" . $app['name'] . "</td>"
					. "<td>" . $app['description'] . "</td>"
					. "<td>" . $app['category'] . "</td>"
					. "<td>" . $app['version'] . "</td>"
					. "<td>" . $providerLink . $docuLink . "</td></tr>";
			}
			$table .= "</table>"
							.	"<div class='text-center'><input type='button' class='btn btn-default' value='". MARKET_INSTALL_BTN ."' onclick='install()'></div><br/>";
		}
		else if (count($apps) == 0 && is_array($apps)) {
			$table = "<font color='red'>There are no apps for this device</font><br/>";
		}
	}
	echo $table;
}

if (isset($_POST['param'])) {
	$result = checkCloud();

	foreach (explode(',', $_POST['param']) as $param) {
		file_put_contents('/tmp/app', $param, FILE_APPEND);
		$apps = $cloud->send('getAppList', array('app_key' => $result, 'idapp' => $param));
		file_put_contents("/tmp/app.tar.gz", $apps);

		$fileName = "app.tar.gz";
		$image_dir = "/tmp/images";
		@mkdir($image_dir);
		if (is_dir($image_dir) && ($dh = opendir($image_dir))) {
			while (($file = readdir($dh)) != false) {
				if (strlen($file) > 7 && substr_compare($file, ".tar.gz", -7, 7) == 0) {
					$file_ = $image_dir . '/' . $file;
					if (strlen($file_) != 0 && file_exists($file_))
						unlink($file_);
				}
				if ($file == "content.txt") {
					$file_ = $image_dir . '/' . $file;
					if (strlen($file_) != 0 && file_exists($file_))
						unlink($file_);
				}
			}
		}
		$split_ext = explode(".", $fileName);

		if ($split_ext[count($split_ext) - 1] == "gz" && $split_ext[count($split_ext) - 2] == "tar" && count($split_ext) >= 3) {
			$upload_file = $image_dir . '/' . $fileName;
			if ((filesize("/tmp/" . $fileName) / 1024) / 1024 <= 7.9) {
				system("/bin/mv /tmp/" . $fileName . " " . $image_dir);
				if (strlen($fileName) != 0 && file_exists($image_dir . '/' . $fileName))
					system("/usr/sbin/userapp_pkg_install.sh $fileName >/var/log/cloud-updateFW.log");
			}
		}
	}

	echo getInstalledApps();
}

if (isset($_POST['del_param'])) {
	$appDel = $_POST['del_param'];
	exec("/usr/local/sbin/userapp_uninstall.sh " . $appDel);
	echo getInstalledApps();
}
if (isset($_POST['menu'])) {
	$directory_not_empty = FALSE;
	if ($dh = @opendir("/home/admin/apps/")) {
		while (($file = readdir($dh)) !== false) {
			if ($file != "." && $file != "..")
				$directory_not_empty = TRUE;
		}
		closedir($dh);
	}

	$app_menu = "";
	if ($directory_not_empty) {
		if ($dh = @opendir("/home/admin/apps/")) {
			while (($file = readdir($dh)) !== false) {
				//$ret.="found file: $file";
				if ($file != "." && $file != "..")
					$app_menu .= "<li><a href='/userapp/$file/index.php'>" . $file . "</a></li>";
			}
			closedir($dh);
		}
	}
	$app_menu .= "<li><a href='index.php?m=Market' id='market'>" . MENU_MARKET . "</a></li></ul>";
	echo $app_menu;
}
?>

==> appfs-24.01.02-rc05.tar.gz: usr/local/www/berogui/modules/Market/market_ajax.php <==
<?php
require_once("/usr/local/www/berogui/includes/Helper/Helper.php");

$exec_ajax = 1;
$invalid = array();

/* [CHECKING GET REQUEST] */
unset($_GET);

/* [CHECKING POST REQUEST] */
$list_post = array('del_param' => 'file-exists', 'menu' => 'select', 'get_installed' => 'select', 'a' => 'select', 'param' => 'id');

$list_options = array(	'del_param' 	=> array('/apps')	,
			'menu'		=> array('get')		,
			'get_installed'	=> array('get')		,
			'a'		=> array('get_app')	);

$_POST = Helper::sanitizePost($_POST, $list_post, $exec_ajax, $invalid, $list_options);

/* [EXECUTING AJAX] */
if (!$exec_ajax) {
        echo "<script>window.location='../../index.php?m=Market&error=1&request={$invalid['request']}&checkor={$invalid['checkor']}&key={$invalid['key']}'</script>";
	exit(1);
}

chdir("../..");
include "./includes/variables.php";
include_once("/usr/www/include/SQLite2ToSQLite3.php");
include "./misc/database.php";
$ba = new beroAri();
require_once("./includes/lang.php");
require_once('/usr/local/www/berogui/includes/session.php');

require_once('/usr/php/include/SbcApi.php');
$cloud = new SbcApi(null, $ba);

function checkCloud() {
	global $cloud;
	$res = $cloud->send('getAppListCheck');
	$res .= "beroNetF231";
	return md5($res);
}

function getInstalledApps() {
	$table = "<table class='table table-striped table-bordered' id='table'>";
	$apps = Helper::getAppList();
	foreach ($apps as $file) {
		$table .= "
		<tr>
			<td>" . $file . "</td>
			<td>
			<img src='./includes/images/delete.png' onclick=\"del('" . $file . "');\"></img>
			</td>
		</tr>";
	}
	$table .= "</table><br/>";

	// TODO: is $error_msg useful ?
	return $error_msg . $table;
}

if (isset($_POST['get_installed'])) {
	echo getInstalledApps();
}
if ($_POST['a'] == 'get_app') {

	$result = checkCloud();
	$apps = $cloud->send('getAppList', array('app_key' => $result), array(), $info);
	if ($apps == false) {
		if ($info['http_code'] == 400 || $info['http_code'] == 401) {
			$table = "<font color='red'>Invalid app key</font><br/>";
		} 
		else {
			$table = "<font color='red'>Error, please check your cloud and network settings.</font><br/>";
		}
	}
	else {
		$apps = unserialize($apps);
		if (count($apps) >= 1 && is_array($apps)) {
			$table = "<table class='table table-striped table-bordered'>";
			$table .= "<tr>"
							. "<th></th>"
							. "<th>" . MARKET_NAME . "</th>"
							. "<th>" . MARKET_DESCRIPTION . "</th>"
							. "<th>" . MARKET_CATEGORY . "</th>"
							.	"<th>" . MARKET_VERSION . "</th>"
							. "<th>" . MARKET_PROVIDER . "</th>"
							. "</tr>";
			foreach ($apps as $app) {
				($app['providerLink'] != null) ? $providerLink = "<a href='" . $app['providerLink'] . "' target='_blank'>" . $app['provider'] . "</a>" : $providerLink = $app['provider'];
				($app['docuLink'] != null) ? $docuLink = "<br><a href='" . $app['docuLink'] . "' target='_blank'>Documentation</a>" : $docuLink = "";
				$table .= "<tr>"
					. "<td><input type='checkbox' class='installApp' value='" . $app['id'] . "'></td>"
					. "<td>" . $app['name'] . "</td>"
					. "<td>" . $app['description'] . "</td>"
					. "<td>" . $app['category'] . "</td>"
					. "<td>" . $app['version'] . "</td>"
					. "<td>" . $providerLink . $docuLink . "</td></tr>";
			}
			$table .= "</table>"
							.	"<div class='text-center'><input type='button' class='btn btn-default' value='". MARKET_INSTALL_BTN ."' onclick='install()'></div><br/>";
		}
		else if (count($apps) == 0 && is_array($apps)) {
			$table = "<font color='red'>There are no apps for this device</font><br/>";
		}
	}
	echo $table;
}

if (isset($_POST['param'])) {
	$result = checkCloud();

	foreach (explode(',', $_POST['param']) as $param) {
		file_put_contents('/tmp/app', $param, FILE_APPEND);
		$apps = $cloud->send('getAppList', array('app_key' => $result, 'idapp' => $param));
		file_put_contents("/tmp/app.tar.gz", $apps);

		$fileName = "app.tar.gz";
		$image_dir = "/tmp/images";
		@mkdir($image_dir);
		if (is_dir($image_dir) && ($dh = opendir($image_dir))) {
			while (($file = readdir($dh)) != false) {
				if (strlen($file) > 7 && substr_compare($file, ".tar.gz", -7, 7) == 0) {
					$file_ = $image_dir . '/' . $file;
					if (strlen($file_) != 0 && file_exists($file_))
						unlink($file_);
				}
				if ($file == "content.txt") {
					$file_ = $image_dir . '/' . $file;
					if (strlen($file_) != 0 && file_exists($file_))
						unlink($file_);
				}
			}
		}
		$split_ext = explode(".", $fileName);

		if ($split_ext[count($split_ext) - 1] == "gz" && $split_ext[count($split_ext) - 2] == "tar" && count($split_ext) >= 3) {
			$upload_file = $image_dir . '/' . $fileName;
			if ((filesize("/tmp/" . $fileName) / 1024) / 1024 <= 7.9) {
				system("/bin/mv /tmp/" . $fileName . " " . $image_dir);
				if (strlen($fileName) != 0 && file_exists($image_dir . '/' . $fileName))
					system("/usr/sbin/userapp_pkg_install.sh $fileName >/var/log/cloud-updateFW.log");
			}
		}
	}

	echo getInstalledApps();
}

if (isset($_POST['del_param'])) {
	$appDel = $_POST['del_param'];
	exec("/usr/local/sbin/userapp_uninstall.sh " . $appDel);
	echo getInstalledApps();
}
if (isset($_POST['menu'])) {
	$directory_not_empty = FALSE;
	if ($dh = @opendir("/home/admin/apps/")) {
		while (($file = readdir($dh)) !== false) {
			if ($file != "." && $file != "..")
				$directory_not_empty = TRUE;
		}
		closedir($dh);
	}

	$app_menu = "";
	if ($directory_not_empty) {
		if ($dh = @opendir("/home/admin/apps/")) {
			while (($file = readdir($dh)) !== false) {
				//$ret.="found file: $file";
				if ($file != "." && $file != "..")
					$app_menu .= "<li><a href='/userapp/$file/index.php'>" . $file . "</a></li>";
			}
			closedir($dh);
		}
	}
	$app_menu .= "<li><a href='index.php?m=Market' id='market'>" . MENU_MARKET . "</a></li></ul>";
	echo $app_menu;
}
?>
